#!/usr/bin/env bash

# Copyright (c) 2020 PaperCut Software International Pty. Ltd.
#
# This is meant to be called by the initialise.sh script from the root directory of
# the application.  See the root initialise.sh script for details
#
# This script is meant to be run as a non-root user

set -xu

# This script assumes all the necessary executables to start the Print Deploy
# user services are in the same directory
CURRENT_DIR=$(cd "$(dirname "${0}")" && pwd)

# executable names
USERCONTEXTSERVICE_EXE_NAME="usercontextservice"
WEBVIEW_EXE_NAME="pc-webview"

# app window vars
SERVICE_APP_URL=http://127.0.0.1:9176/app
SERVICE_APP_WINDOW_WIDTH=950
SERVICE_APP_WINDOW_HEIGHT=500

# script flags
# If true, running this script will also open the Print Deploy app window
DISPLAY_APP_WINDOW="false"

printUsage() {
    echo "-h  print usage"
    echo "-w  flag to open the Print Deploy Client window"
}

validateArgs() {
    while getopts "hw" flag; do
        case $flag in
        h)
            printUsage
            exit 0
            ;;
        w) DISPLAY_APP_WINDOW="true" ;;
        *)
            echo "ERROR: unknown flag provided: ${flag}"
            exit 1
            ;;
        esac
    done

    echo "CURRENT_DIR=${CURRENT_DIR}"
    echo "DISPLAY_APP_WINDOW=${DISPLAY_APP_WINDOW}"
}

runUserContextService() {
    # Do not run usercontextservice as root
    if [[ $EUID -eq 0 ]]; then
        echo "ERROR: This script cannot be run as root"
        exit 1
    fi
    # Check if usercontextservice is already running
    if output=$(pgrep -x "${USERCONTEXTSERVICE_EXE_NAME}" -u "$USER"); then
        echo "${USERCONTEXTSERVICE_EXE_NAME} is already running. process id: ${output}"
        return
    fi
    # Run usercontextservice if it isn't running yet
    "${CURRENT_DIR}/${USERCONTEXTSERVICE_EXE_NAME}" -pclog.dev &
}

openAppWindow() {
    # usercontextservice binary may not be ready to serve yet, brute force a delay here
    sleep 2
    # Do not run pc-webview as root
    if [[ $EUID -eq 0 ]]; then
        echo "ERROR: This script cannot be run as root"
        exit 1
    fi

    # check if this script was called to also display app window
    if [[ "${DISPLAY_APP_WINDOW}" == "true" ]]; then
        # check if another window is already running
        if output=$(pgrep -x "${WEBVIEW_EXE_NAME}" -u "$USER"); then
            echo "${WEBVIEW_EXE_NAME} is already running. process id: ${output}"
            return
        fi
        # run only if there's no other window running
        "${CURRENT_DIR}/${WEBVIEW_EXE_NAME}" \
            -url "${SERVICE_APP_URL}" \
            -width $SERVICE_APP_WINDOW_WIDTH \
            -height $SERVICE_APP_WINDOW_HEIGHT
    fi
}

main() {
    validateArgs "$@"
    runUserContextService
    openAppWindow
}

main "$@"
