#!/bin/bash
#
# Turn on or off certain Print Provider configuration variables
#

# Is a Mac return 0 or 1 otherwise (for Linux)
_is_mac() {
    if [ "$(uname)" = "Darwin" ]; then
        return 0
    fi
    return 1
}

# Is it using systemd
_is_systemd() {
    if [ "`cat /proc/1/comm`" = "systemd" ]; then
        return 0
    fi
    return 1
}

# Print the pid of the given process name
# Note: pidof(1) doesn't exist on Mac
_pidof() {
    psname=$1
    ps -ef | grep ${psname}$ | awk '{print $2}'
}

_restart_monitor() {
    prepid=$(_pidof pc-event-monitor)
    echo "Restarting the print provider [$prepid]..."

    if _is_mac; then
        sudo launchctl stop ${CUPS_PREFIX}.pc-event-monitor
    elif _is_systemd; then
        sudo systemctl restart pc-event-monitor.service
    else
        sudo /etc/init.d/${CUPS_PREFIX}-event-monitor restart
    fi

    # found in QA if restarted too many times too quickly it would fail to start???
    sleep 2

    postpid=$(_pidof pc-event-monitor)
    echo "New print provider [$postpid]"
}

_usage() {
    echo "usage: $prog [-d|-D|-s] [-i|-I] [-n] [-r|R] [-h|-?]"
    echo "without options will print relevant config settings"
    echo "options include:"
    echo " -d turn on debugging"
    echo " -D turn off debugging"
    echo " -s turn on debug snapshotting of spool"
    echo " -i turn on auto importing of printers"
    echo " -I turn off auto importing of printers"
    echo " -r restart pc-event-monitor (default)"
    echo " -R do NOT restart pc-event-monitor"
    echo " -n non-interactive"
    echo " -h this usage message"
    echo " -? this usage message"
    exit 0
}

_print_configs() {
   echo "The current relevant Print Provider configuration settings are:"
   egrep "^#*debug=|^#*EnablePrinterAutoImport=" print-provider.conf
}

# Handle stuff without .common and without installer replacing @@ vars
CUPS_PREFIX="papercut"
if echo "$CUPS_PREFIX" | egrep "^@unix" >/dev/null; then
    # Using non installed version so just default to papercut
    CUPS_PREFIX="papercut"
fi
APP_USER="papercut"
if echo "$APP_USER" | egrep "^@unix" >/dev/null; then
    # Using non installed version so just default to papercut
    APP_USER="papercut"
fi

prog="$(basename "$0")"
ppdir="$(dirname "$0")"
cd $ppdir

# No args then just print out the existing configs
if [ "$#" -eq 0 ]; then
   _print_configs
   exit 0
fi

debug=false
nodebug=false
snapshot=false
import=false
noimport=false
interactive=true
doconfig=false
dorestart=true

while getopts 'dDsiIrRhn?' c
do
  case $c in
    d) debug=true; doconfig=true ;;
    D) nodebug=true; doconfig=true ;;
    s) snapshot=true; doconfig=true ;;
    i) import=true; doconfig=true ;;
    I) noimport=true; doconfig=true ;;
    r) dorestart=true ;;
    R) dorestart=false ;;
    n) interactive=false ;;
    *) _usage ;;
  esac
done


if $doconfig; then
    echo "This script will modify certain configurations for the print provider on this system."
    echo "Hostname: `hostname`"
    echo
fi

if $dorestart; then
    echo "The print provider will be automatically restarted."
    echo
fi

if $interactive; then
    read -p "Are you sure? [y/n] " -n 1
    if [[ ! $REPLY =~ ^[Yy]$ ]]
    then
        echo ""
        echo "No configurations have been changed."
        exit 1
    fi
    echo
fi

echo "Enter your sudo password if requested/required:"

if $doconfig; then

    # Modify the print-provider.conf file
    $debug && sudo sed -ie "s/^#*debug=.*/debug=on/" print-provider.conf
    $nodebug && sudo sed -ie s/^#*debug=.*/debug=off/ print-provider.conf
    $snapshot && sudo sed -ie s/^#*debug=.*/debug=snapshot/ print-provider.conf
    $import && sudo sed -ie s/^#*EnablePrinterAutoImport=.*/EnablePrinterAutoImport=on/ print-provider.conf
    $noimport && sudo sed -ie s/^#*EnablePrinterAutoImport=.*/EnablePrinterAutoImport=off/ print-provider.conf

    _print_configs
    echo
fi

$dorestart && _restart_monitor
